{
    "$graph": [
        {
            "class": "Workflow",
            "label": "LodSeq",
            "doc": "LodSeq performs the genetic linkage analysis across families, by computing\nlod-scores given a gvcf file and a related tfam pedigree file.\n",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/chromosomes"
                },
                {
                    "type": "File",
                    "id": "#main/dom_model"
                },
                {
                    "type": "Directory",
                    "id": "#main/genetic_maps"
                },
                {
                    "type": "float",
                    "id": "#main/lod_threshold"
                },
                {
                    "type": "string",
                    "id": "#main/out_prefix"
                },
                {
                    "type": "File",
                    "id": "#main/rec_model"
                },
                {
                    "type": "File",
                    "id": "#main/tfam"
                },
                {
                    "type": "File",
                    "id": "#main/vcf"
                }
            ],
            "steps": [
                {
                    "run": "#merge.cwl",
                    "in": [
                        {
                            "source": "#main/runMultiPointMerlin/out_dom_woheader_txt",
                            "id": "#main/mergeResults/files_multi_dom"
                        },
                        {
                            "source": "#main/runMultiPointMerlin/out_rec_woheader_txt",
                            "id": "#main/mergeResults/files_multi_rec"
                        },
                        {
                            "source": "#main/runSinglePointMerlin/out_dom_woheader_txt",
                            "id": "#main/mergeResults/files_sgl_dom"
                        },
                        {
                            "source": "#main/runSinglePointMerlin/out_rec_woheader_txt",
                            "id": "#main/mergeResults/files_sgl_rec"
                        }
                    ],
                    "out": [
                        "#main/mergeResults/out_merged_sgl_dom_txt",
                        "#main/mergeResults/out_merged_sgl_rec_txt",
                        "#main/mergeResults/out_merged_multi_dom_txt",
                        "#main/mergeResults/out_merged_multi_rec_txt",
                        "#main/mergeResults/out_dir_m"
                    ],
                    "id": "#main/mergeResults"
                },
                {
                    "run": "#prepareGeneticMaps.cwl",
                    "in": [
                        {
                            "source": "#main/chromosomes",
                            "id": "#main/prepareGeneticMaps/chromosome"
                        },
                        {
                            "source": "#main/genetic_maps",
                            "id": "#main/prepareGeneticMaps/genetic_maps"
                        }
                    ],
                    "scatter": "#main/prepareGeneticMaps/chromosome",
                    "out": [
                        "#main/prepareGeneticMaps/out_genmap",
                        "#main/prepareGeneticMaps/out_dir_pgm"
                    ],
                    "id": "#main/prepareGeneticMaps"
                },
                {
                    "run": "#prepareMultiPointFiles.cwl",
                    "in": [
                        {
                            "source": "#main/prepareGeneticMaps/out_genmap",
                            "id": "#main/prepareMultiPointFiles/chr_genmap"
                        },
                        {
                            "source": "#main/splitByChrom/out_chr_map",
                            "id": "#main/prepareMultiPointFiles/chr_map"
                        },
                        {
                            "source": "#main/splitByChrom/out_chr_ped",
                            "id": "#main/prepareMultiPointFiles/chr_ped"
                        },
                        {
                            "source": "#main/chromosomes",
                            "id": "#main/prepareMultiPointFiles/chromosome"
                        },
                        {
                            "source": "#main/out_prefix",
                            "id": "#main/prepareMultiPointFiles/out_prefix"
                        }
                    ],
                    "scatter": [
                        "#main/prepareMultiPointFiles/chr_map",
                        "#main/prepareMultiPointFiles/chr_ped",
                        "#main/prepareMultiPointFiles/chr_genmap",
                        "#main/prepareMultiPointFiles/chromosome"
                    ],
                    "scatterMethod": "dotproduct",
                    "out": [
                        "#main/prepareMultiPointFiles/out_chr_dat",
                        "#main/prepareMultiPointFiles/out_chr_map",
                        "#main/prepareMultiPointFiles/out_chr_ped",
                        "#main/prepareMultiPointFiles/out_dir_pmf"
                    ],
                    "id": "#main/prepareMultiPointFiles"
                },
                {
                    "run": "#prepareSinglePointFiles.cwl",
                    "in": [
                        {
                            "source": "#main/splitByChrom/out_chr_map",
                            "id": "#main/prepareSinglePointFiles/chr_map"
                        },
                        {
                            "source": "#main/chromosomes",
                            "id": "#main/prepareSinglePointFiles/chromosome"
                        },
                        {
                            "source": "#main/out_prefix",
                            "id": "#main/prepareSinglePointFiles/out_prefix"
                        }
                    ],
                    "scatter": [
                        "#main/prepareSinglePointFiles/chromosome",
                        "#main/prepareSinglePointFiles/chr_map"
                    ],
                    "scatterMethod": "dotproduct",
                    "out": [
                        "#main/prepareSinglePointFiles/out_chr_dat",
                        "#main/prepareSinglePointFiles/out_chr_map",
                        "#main/prepareSinglePointFiles/out_dir_psf"
                    ],
                    "id": "#main/prepareSinglePointFiles"
                },
                {
                    "run": "#prepareVCF.cwl",
                    "requirements": [
                        {
                            "coresMin": 1,
                            "coresMax": 12,
                            "class": "ResourceRequirement"
                        }
                    ],
                    "in": [
                        {
                            "source": "#main/out_prefix",
                            "id": "#main/prepareVCF/out_prefix"
                        },
                        {
                            "source": "#main/tfam",
                            "id": "#main/prepareVCF/tfam"
                        },
                        {
                            "source": "#main/vcf",
                            "id": "#main/prepareVCF/vcf"
                        }
                    ],
                    "out": [
                        "#main/prepareVCF/out_map",
                        "#main/prepareVCF/out_ped",
                        "#main/prepareVCF/out_dir"
                    ],
                    "id": "#main/prepareVCF"
                },
                {
                    "run": "#runMultiPointMerlin.cwl",
                    "in": [
                        {
                            "source": "#main/prepareMultiPointFiles/out_chr_dat",
                            "id": "#main/runMultiPointMerlin/chr_dat"
                        },
                        {
                            "source": "#main/prepareMultiPointFiles/out_chr_map",
                            "id": "#main/runMultiPointMerlin/chr_map"
                        },
                        {
                            "source": "#main/prepareMultiPointFiles/out_chr_ped",
                            "id": "#main/runMultiPointMerlin/chr_ped"
                        },
                        {
                            "source": "#main/chromosomes",
                            "id": "#main/runMultiPointMerlin/chromosome"
                        },
                        {
                            "source": "#main/dom_model",
                            "id": "#main/runMultiPointMerlin/dom_model"
                        },
                        {
                            "source": "#main/lod_threshold",
                            "id": "#main/runMultiPointMerlin/lod_threshold"
                        },
                        {
                            "source": "#main/rec_model",
                            "id": "#main/runMultiPointMerlin/rec_model"
                        }
                    ],
                    "scatter": [
                        "#main/runMultiPointMerlin/chromosome",
                        "#main/runMultiPointMerlin/chr_dat",
                        "#main/runMultiPointMerlin/chr_map",
                        "#main/runMultiPointMerlin/chr_ped"
                    ],
                    "scatterMethod": "dotproduct",
                    "out": [
                        "#main/runMultiPointMerlin/out_dom_txt",
                        "#main/runMultiPointMerlin/out_rec_txt",
                        "#main/runMultiPointMerlin/out_dom_signif_txt",
                        "#main/runMultiPointMerlin/out_rec_signif_txt",
                        "#main/runMultiPointMerlin/out_dom_woheader_txt",
                        "#main/runMultiPointMerlin/out_rec_woheader_txt",
                        "#main/runMultiPointMerlin/out_dir_rmm"
                    ],
                    "id": "#main/runMultiPointMerlin"
                },
                {
                    "run": "#runSinglePointMerlin.cwl",
                    "in": [
                        {
                            "source": "#main/prepareSinglePointFiles/out_chr_dat",
                            "id": "#main/runSinglePointMerlin/chr_dat"
                        },
                        {
                            "source": "#main/prepareSinglePointFiles/out_chr_map",
                            "id": "#main/runSinglePointMerlin/chr_map"
                        },
                        {
                            "source": "#main/splitByChrom/out_chr_ped",
                            "id": "#main/runSinglePointMerlin/chr_ped"
                        },
                        {
                            "source": "#main/chromosomes",
                            "id": "#main/runSinglePointMerlin/chromosome"
                        },
                        {
                            "source": "#main/dom_model",
                            "id": "#main/runSinglePointMerlin/dom_model"
                        },
                        {
                            "source": "#main/lod_threshold",
                            "id": "#main/runSinglePointMerlin/lod_threshold"
                        },
                        {
                            "source": "#main/rec_model",
                            "id": "#main/runSinglePointMerlin/rec_model"
                        }
                    ],
                    "scatter": [
                        "#main/runSinglePointMerlin/chromosome",
                        "#main/runSinglePointMerlin/chr_dat",
                        "#main/runSinglePointMerlin/chr_map",
                        "#main/runSinglePointMerlin/chr_ped"
                    ],
                    "scatterMethod": "dotproduct",
                    "out": [
                        "#main/runSinglePointMerlin/out_dom_txt",
                        "#main/runSinglePointMerlin/out_rec_txt",
                        "#main/runSinglePointMerlin/out_dom_signif_txt",
                        "#main/runSinglePointMerlin/out_rec_signif_txt",
                        "#main/runSinglePointMerlin/out_dom_woheader_txt",
                        "#main/runSinglePointMerlin/out_rec_woheader_txt",
                        "#main/runSinglePointMerlin/out_dir_rsm"
                    ],
                    "id": "#main/runSinglePointMerlin"
                },
                {
                    "run": "#splitByChrom.cwl",
                    "in": [
                        {
                            "source": "#main/chromosomes",
                            "id": "#main/splitByChrom/chromosome"
                        },
                        {
                            "source": "#main/prepareVCF/out_map",
                            "id": "#main/splitByChrom/map"
                        },
                        {
                            "source": "#main/out_prefix",
                            "id": "#main/splitByChrom/out_prefix"
                        },
                        {
                            "source": "#main/prepareVCF/out_ped",
                            "id": "#main/splitByChrom/ped"
                        }
                    ],
                    "scatter": "#main/splitByChrom/chromosome",
                    "out": [
                        "#main/splitByChrom/out_chr_map",
                        "#main/splitByChrom/out_chr_ped",
                        "#main/splitByChrom/out_dir_sbc"
                    ],
                    "id": "#main/splitByChrom"
                }
            ],
            "id": "#main",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0002-0929-8603",
                    "https://schema.org/email": "mailto:elise.larsonneur@cea.fr",
                    "https://schema.org/name": "Elise Larsonneur"
                }
            ],
            "https://schema.org/citation": "https://dx.doi.org/10.1109/BIBM.2018.8621141",
            "https://schema.org/codeRepository": "https://github.com/CNRGH/WMS-benchmark",
            "https://schema.org/license": "https://spdx.org/licenses/CECILL-2.1",
            "https://schema.org/keywords": "edam:operation_0283",
            "outputs": [
                {
                    "type": "Directory",
                    "outputSource": "#main/prepareVCF/out_dir",
                    "id": "#main/out_dir"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/mergeResults/out_dir_m",
                    "id": "#main/out_dir_mr"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "outputSource": "#main/prepareGeneticMaps/out_dir_pgm",
                    "id": "#main/out_dir_pgm"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "outputSource": "#main/prepareMultiPointFiles/out_dir_pmf",
                    "id": "#main/out_dir_pmf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "outputSource": "#main/prepareSinglePointFiles/out_dir_psf",
                    "id": "#main/out_dir_psf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "outputSource": "#main/runMultiPointMerlin/out_dir_rmm",
                    "id": "#main/out_dir_rmm"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "outputSource": "#main/runSinglePointMerlin/out_dir_rsm",
                    "id": "#main/out_dir_rsm"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "outputSource": "#main/splitByChrom/out_dir_sbc",
                    "id": "#main/out_dir_sbc"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "baseCommand": [],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "streamable": true,
                    "id": "#merge.cwl/files_multi_dom"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "streamable": true,
                    "id": "#merge.cwl/files_multi_rec"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "streamable": true,
                    "id": "#merge.cwl/files_sgl_dom"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "streamable": true,
                    "id": "#merge.cwl/files_sgl_rec"
                }
            ],
            "arguments": [
                "mkdir",
                "-p",
                "mergeResults",
                "&&",
                "cat",
                "$(inputs.files_sgl_dom)",
                ">",
                "mergeResults/results_singlepoint_merged_dominant.txt",
                "&&",
                "cat",
                "$(inputs.files_sgl_rec)",
                ">",
                "mergeResults/results_singlepoint_merged_recessive.txt",
                "&&",
                "cat",
                "$(inputs.files_multi_dom)",
                ">",
                "mergeResults/results_multipoint_merged_dominant.txt",
                "&&",
                "cat",
                "$(inputs.files_multi_rec)",
                ">",
                "mergeResults/results_multipoint_merged_recessive.txt"
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "mergeResults"
                    },
                    "id": "#merge.cwl/out_dir_m"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "mergeResults/results_multipoint_merged_dominant.txt"
                    },
                    "id": "#merge.cwl/out_merged_multi_dom_txt"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "mergeResults/results_multipoint_merged_recessive.txt"
                    },
                    "id": "#merge.cwl/out_merged_multi_rec_txt"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "mergeResults/results_singlepoint_merged_dominant.txt"
                    },
                    "id": "#merge.cwl/out_merged_sgl_dom_txt"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "mergeResults/results_singlepoint_merged_recessive.txt"
                    },
                    "id": "#merge.cwl/out_merged_sgl_rec_txt"
                }
            ],
            "stdout": "mergeResults/mergeResults.o",
            "stderr": "mergeResults/mergeResults.e",
            "id": "#merge.cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0002-0929-8603",
                    "https://schema.org/email": "mailto:elise.larsonneur@cea.fr",
                    "https://schema.org/name": "Elise Larsonneur"
                }
            ],
            "https://schema.org/citation": "https://dx.doi.org/10.1109/BIBM.2018.8621141",
            "https://schema.org/codeRepository": "https://github.com/CNRGH/WMS-benchmark",
            "https://schema.org/license": "https://spdx.org/licenses/CECILL-2.1"
        },
        {
            "class": "CommandLineTool",
            "label": "prepareGeneticMaps",
            "doc": "prepareGeneticMaps\n   removes header from genetic map file(s) \n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "baseCommand": [],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-c"
                    },
                    "id": "#prepareGeneticMaps.cwl/chromosome"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-g"
                    },
                    "id": "#prepareGeneticMaps.cwl/genetic_maps"
                }
            ],
            "arguments": [
                "mkdir",
                "-p",
                "prepareGeneticMaps",
                "prepareGeneticMaps/$(inputs.chromosome)",
                "&&",
                "~/WMS-benchmark/LodSeq/scripts/prepareGeneticMaps.sh",
                "-o",
                "prepareGeneticMaps/$(inputs.chromosome)"
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "prepareGeneticMaps"
                    },
                    "id": "#prepareGeneticMaps.cwl/out_dir_pgm"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "prepareGeneticMaps/$(inputs.chromosome)/genetic_map_GRCh37_chr$(inputs.chromosome)_wo_head.txt"
                    },
                    "id": "#prepareGeneticMaps.cwl/out_genmap"
                }
            ],
            "stdout": "prepareGeneticMaps/$(inputs.chromosome)/prepareGeneticMaps.o",
            "stderr": "prepareGeneticMaps/$(inputs.chromosome)/prepareGeneticMaps.e",
            "id": "#prepareGeneticMaps.cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0002-0929-8603",
                    "https://schema.org/email": "mailto:elise.larsonneur@cea.fr",
                    "https://schema.org/name": "Elise Larsonneur"
                }
            ],
            "https://schema.org/citation": "https://dx.doi.org/10.1109/BIBM.2018.8621141",
            "https://schema.org/codeRepository": "https://github.com/CNRGH/WMS-benchmark",
            "https://schema.org/license": "https://spdx.org/licenses/CECILL-2.1"
        },
        {
            "class": "CommandLineTool",
            "label": "prepareMultiPointFiles",
            "doc": "prepareMultiPointFiles\n   prepare multipoint merlin analysis inputs  \n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "baseCommand": [],
            "inputs": [
                {
                    "type": "File",
                    "id": "#prepareMultiPointFiles.cwl/chr_genmap"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "id": "#prepareMultiPointFiles.cwl/chr_map"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#prepareMultiPointFiles.cwl/chr_ped"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-c"
                    },
                    "id": "#prepareMultiPointFiles.cwl/chromosome"
                },
                {
                    "type": "string",
                    "id": "#prepareMultiPointFiles.cwl/out_prefix"
                }
            ],
            "arguments": [
                "mkdir",
                "-p",
                "prepareMultiPointFiles",
                "$('prepareMultiPointFiles/' + inputs.chromosome)",
                "&&",
                "~/WMS-benchmark/LodSeq/scripts/prepareMultiPointFiles.sh",
                "-g",
                "$(inputs.chr_genmap.dirname)",
                "-o",
                "$('prepareMultiPointFiles/' + inputs.chromosome)",
                "-s",
                "$(inputs.out_prefix + '_multi_chr')",
                "-t",
                "$(runtime.cores)"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "prepareMultiPointFiles/$(inputs.chromosome)/$(inputs.out_prefix)_multi_chr$(inputs.chromosome).dat"
                    },
                    "id": "#prepareMultiPointFiles.cwl/out_chr_dat"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "prepareMultiPointFiles/$(inputs.chromosome)/$(inputs.out_prefix)_multi_chr$(inputs.chromosome).map"
                    },
                    "id": "#prepareMultiPointFiles.cwl/out_chr_map"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "prepareMultiPointFiles/$(inputs.chromosome)/$(inputs.out_prefix)_multi_chr$(inputs.chromosome).ped"
                    },
                    "id": "#prepareMultiPointFiles.cwl/out_chr_ped"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "prepareMultiPointFiles"
                    },
                    "id": "#prepareMultiPointFiles.cwl/out_dir_pmf"
                }
            ],
            "stdout": "prepareMultiPointFiles/$(inputs.chromosome)/prepareMultiPointFiles.o",
            "stderr": "prepareMultiPointFiles/$(inputs.chromosome)/prepareMultiPointFiles.e",
            "id": "#prepareMultiPointFiles.cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0002-0929-8603",
                    "https://schema.org/email": "mailto:elise.larsonneur@cea.fr",
                    "https://schema.org/name": "Elise Larsonneur"
                }
            ],
            "https://schema.org/citation": "https://dx.doi.org/10.1109/BIBM.2018.8621141",
            "https://schema.org/codeRepository": "https://github.com/CNRGH/WMS-benchmark",
            "https://schema.org/license": "https://spdx.org/licenses/CECILL-2.1"
        },
        {
            "class": "CommandLineTool",
            "label": "prepareSinglePointFiles",
            "doc": "prepareSinglePointFiles\n   prepare single point merlin analysis inputs  \n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "baseCommand": [],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "id": "#prepareSinglePointFiles.cwl/chr_map"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-c"
                    },
                    "id": "#prepareSinglePointFiles.cwl/chromosome"
                },
                {
                    "type": "string",
                    "id": "#prepareSinglePointFiles.cwl/out_prefix"
                }
            ],
            "arguments": [
                "mkdir",
                "-p",
                "prepareSinglePointFiles",
                "$('prepareSinglePointFiles/' + inputs.chromosome)",
                "&&",
                "~/WMS-benchmark/LodSeq/scripts/prepareSinglePointFiles.sh",
                "-o",
                "$('prepareSinglePointFiles/' + inputs.chromosome)",
                "-s",
                "$(inputs.out_prefix + '_sgl_chr')"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "prepareSinglePointFiles/$(inputs.chromosome)/$(inputs.out_prefix)_sgl_chr$(inputs.chromosome).dat"
                    },
                    "id": "#prepareSinglePointFiles.cwl/out_chr_dat"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "prepareSinglePointFiles/$(inputs.chromosome)/$(inputs.out_prefix)_sgl_chr$(inputs.chromosome).map"
                    },
                    "id": "#prepareSinglePointFiles.cwl/out_chr_map"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "prepareSinglePointFiles"
                    },
                    "id": "#prepareSinglePointFiles.cwl/out_dir_psf"
                }
            ],
            "stdout": "prepareSinglePointFiles/$(inputs.chromosome)/prepareSinglePointFiles.o",
            "stderr": "prepareSinglePointFiles/$(inputs.chromosome)/prepareSinglePointFiles.e",
            "id": "#prepareSinglePointFiles.cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0002-0929-8603",
                    "https://schema.org/email": "mailto:elise.larsonneur@cea.fr",
                    "https://schema.org/name": "Elise Larsonneur"
                }
            ],
            "https://schema.org/citation": "https://dx.doi.org/10.1109/BIBM.2018.8621141",
            "https://schema.org/codeRepository": "https://github.com/CNRGH/WMS-benchmark",
            "https://schema.org/license": "https://spdx.org/licenses/CECILL-2.1"
        },
        {
            "class": "CommandLineTool",
            "label": "prepareVCF",
            "doc": "prepareVCF\n   get .ped and .map files from .vcf and .tfam files\n   and check that all input files and directories exist\n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "baseCommand": [],
            "inputs": [
                {
                    "type": "string",
                    "id": "#prepareVCF.cwl/out_prefix"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#prepareVCF.cwl/tfam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#prepareVCF.cwl/vcf"
                }
            ],
            "arguments": [
                "mkdir",
                "-p",
                "prepareVCF",
                "&&",
                "~/WMS-benchmark/LodSeq/scripts/prepareVCF.sh",
                "-o",
                "prepareVCF",
                "-s",
                "$(inputs.out_prefix)_vcftools_filled",
                "-t",
                "$(runtime.cores)"
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "prepareVCF"
                    },
                    "id": "#prepareVCF.cwl/out_dir"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "prepareVCF/$(inputs.out_prefix)_vcftools_filled.map"
                    },
                    "id": "#prepareVCF.cwl/out_map"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "prepareVCF/$(inputs.out_prefix)_vcftools_filled.ped"
                    },
                    "id": "#prepareVCF.cwl/out_ped"
                }
            ],
            "stdout": "prepareVCF/prepareVCF.o",
            "stderr": "prepareVCF/prepareVCF.e",
            "id": "#prepareVCF.cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0002-0929-8603",
                    "https://schema.org/email": "mailto:elise.larsonneur@cea.fr",
                    "https://schema.org/name": "Elise Larsonneur"
                }
            ],
            "https://schema.org/citation": "https://dx.doi.org/10.1109/BIBM.2018.8621141",
            "https://schema.org/codeRepository": "https://github.com/CNRGH/WMS-benchmark",
            "https://schema.org/license": "https://spdx.org/licenses/CECILL-2.1"
        },
        {
            "class": "CommandLineTool",
            "label": "runMultiPointMerlin",
            "doc": "runMultiPointMerlin\n   run multi point merlin analysis  \n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "baseCommand": [],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-d"
                    },
                    "id": "#runMultiPointMerlin.cwl/chr_dat"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "id": "#runMultiPointMerlin.cwl/chr_map"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#runMultiPointMerlin.cwl/chr_ped"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-c"
                    },
                    "id": "#runMultiPointMerlin.cwl/chromosome"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-D"
                    },
                    "id": "#runMultiPointMerlin.cwl/dom_model"
                },
                {
                    "type": "float",
                    "inputBinding": {
                        "prefix": "-l"
                    },
                    "id": "#runMultiPointMerlin.cwl/lod_threshold"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-R"
                    },
                    "id": "#runMultiPointMerlin.cwl/rec_model"
                }
            ],
            "arguments": [
                "mkdir",
                "-p",
                "runMultiPointMerlin",
                "$('runMultiPointMerlin/' + inputs.chromosome)",
                "&&",
                "~/WMS-benchmark/LodSeq/scripts/runMultiPointMerlin.sh",
                "-o",
                "$('runMultiPointMerlin/' + inputs.chromosome)",
                "-s",
                "results_multipoint_chr"
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "runMultiPointMerlin"
                    },
                    "id": "#runMultiPointMerlin.cwl/out_dir_rmm"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "runMultiPointMerlin/$(inputs.chromosome)/results_multipoint_chr$(inputs.chromosome)_dominant_LODsignif.txt"
                    },
                    "id": "#runMultiPointMerlin.cwl/out_dom_signif_txt"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "runMultiPointMerlin/$(inputs.chromosome)/results_multipoint_chr$(inputs.chromosome)_dominant.txt"
                    },
                    "id": "#runMultiPointMerlin.cwl/out_dom_txt"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "runMultiPointMerlin/$(inputs.chromosome)/results_multipoint_chr$(inputs.chromosome)_dominant.woheader.txt"
                    },
                    "id": "#runMultiPointMerlin.cwl/out_dom_woheader_txt"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "runMultiPointMerlin/$(inputs.chromosome)/results_multipoint_chr$(inputs.chromosome)_recessive_LODsignif.txt"
                    },
                    "id": "#runMultiPointMerlin.cwl/out_rec_signif_txt"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "runMultiPointMerlin/$(inputs.chromosome)/results_multipoint_chr$(inputs.chromosome)_recessive.txt"
                    },
                    "id": "#runMultiPointMerlin.cwl/out_rec_txt"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "runMultiPointMerlin/$(inputs.chromosome)/results_multipoint_chr$(inputs.chromosome)_recessive.woheader.txt"
                    },
                    "id": "#runMultiPointMerlin.cwl/out_rec_woheader_txt"
                }
            ],
            "stdout": "runMultiPointMerlin/$(inputs.chromosome)/runMultiPointMerlin.o",
            "stderr": "runMultiPointMerlin/$(inputs.chromosome)/runMultiPointMerlin.e",
            "id": "#runMultiPointMerlin.cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0002-0929-8603",
                    "https://schema.org/email": "mailto:elise.larsonneur@cea.fr",
                    "https://schema.org/name": "Elise Larsonneur"
                }
            ],
            "https://schema.org/citation": "https://dx.doi.org/10.1109/BIBM.2018.8621141",
            "https://schema.org/codeRepository": "https://github.com/CNRGH/WMS-benchmark",
            "https://schema.org/license": "https://spdx.org/licenses/CECILL-2.1"
        },
        {
            "class": "CommandLineTool",
            "label": "runSinglePointMerlin",
            "doc": "runSinglePointMerlin\n   run single point merlin analysis  \n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "baseCommand": [],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-d"
                    },
                    "id": "#runSinglePointMerlin.cwl/chr_dat"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "id": "#runSinglePointMerlin.cwl/chr_map"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#runSinglePointMerlin.cwl/chr_ped"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-c"
                    },
                    "id": "#runSinglePointMerlin.cwl/chromosome"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-D"
                    },
                    "id": "#runSinglePointMerlin.cwl/dom_model"
                },
                {
                    "type": "float",
                    "inputBinding": {
                        "prefix": "-l"
                    },
                    "id": "#runSinglePointMerlin.cwl/lod_threshold"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-R"
                    },
                    "id": "#runSinglePointMerlin.cwl/rec_model"
                }
            ],
            "arguments": [
                "mkdir",
                "-p",
                "runSinglePointMerlin",
                "$('runSinglePointMerlin/' + inputs.chromosome)",
                "&&",
                "~/WMS-benchmark/LodSeq/scripts/runSinglePointMerlin.sh",
                "-o",
                "$('runSinglePointMerlin/' + inputs.chromosome)",
                "-s",
                "results_singlepoint_chr"
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "runSinglePointMerlin"
                    },
                    "id": "#runSinglePointMerlin.cwl/out_dir_rsm"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "runSinglePointMerlin/$(inputs.chromosome)/results_singlepoint_chr$(inputs.chromosome)_dominant_LODsignif.txt"
                    },
                    "id": "#runSinglePointMerlin.cwl/out_dom_signif_txt"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "runSinglePointMerlin/$(inputs.chromosome)/results_singlepoint_chr$(inputs.chromosome)_dominant.txt"
                    },
                    "id": "#runSinglePointMerlin.cwl/out_dom_txt"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "runSinglePointMerlin/$(inputs.chromosome)/results_singlepoint_chr$(inputs.chromosome)_dominant.woheader.txt"
                    },
                    "id": "#runSinglePointMerlin.cwl/out_dom_woheader_txt"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "runSinglePointMerlin/$(inputs.chromosome)/results_singlepoint_chr$(inputs.chromosome)_recessive_LODsignif.txt"
                    },
                    "id": "#runSinglePointMerlin.cwl/out_rec_signif_txt"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "runSinglePointMerlin/$(inputs.chromosome)/results_singlepoint_chr$(inputs.chromosome)_recessive.txt"
                    },
                    "id": "#runSinglePointMerlin.cwl/out_rec_txt"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "runSinglePointMerlin/$(inputs.chromosome)/results_singlepoint_chr$(inputs.chromosome)_recessive.woheader.txt"
                    },
                    "id": "#runSinglePointMerlin.cwl/out_rec_woheader_txt"
                }
            ],
            "stdout": "runSinglePointMerlin/$(inputs.chromosome)/runSinglePointMerlin.o",
            "stderr": "runSinglePointMerlin/$(inputs.chromosome)/runSinglePointMerlin.e",
            "id": "#runSinglePointMerlin.cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0002-0929-8603",
                    "https://schema.org/email": "mailto:elise.larsonneur@cea.fr",
                    "https://schema.org/name": "Elise Larsonneur"
                }
            ],
            "https://schema.org/citation": "https://dx.doi.org/10.1109/BIBM.2018.8621141",
            "https://schema.org/codeRepository": "https://github.com/CNRGH/WMS-benchmark",
            "https://schema.org/license": "https://spdx.org/licenses/CECILL-2.1"
        },
        {
            "class": "CommandLineTool",
            "label": "splitByChrom",
            "doc": "splitByChrom\n   split files (.ped .map) by chromosome \n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "baseCommand": [],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-c"
                    },
                    "id": "#splitByChrom.cwl/chromosome"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "id": "#splitByChrom.cwl/map"
                },
                {
                    "type": "string",
                    "id": "#splitByChrom.cwl/out_prefix"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#splitByChrom.cwl/ped"
                }
            ],
            "arguments": [
                "mkdir",
                "-p",
                "splitByChrom",
                "$('splitByChrom/' + inputs.chromosome)",
                "&&",
                "~/WMS-benchmark/LodSeq/scripts/splitByChrom.sh",
                "-o",
                "$('splitByChrom/' + inputs.chromosome)",
                "-s",
                "$(inputs.out_prefix + '_vcftools_filled_chr')",
                "-t",
                "$(runtime.cores)"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "splitByChrom/$(inputs.chromosome)/$(inputs.out_prefix)_vcftools_filled_chr$(inputs.chromosome).map"
                    },
                    "id": "#splitByChrom.cwl/out_chr_map"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "splitByChrom/$(inputs.chromosome)/$(inputs.out_prefix)_vcftools_filled_chr$(inputs.chromosome).ped"
                    },
                    "id": "#splitByChrom.cwl/out_chr_ped"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "splitByChrom"
                    },
                    "id": "#splitByChrom.cwl/out_dir_sbc"
                }
            ],
            "stdout": "splitByChrom/$(inputs.chromosome)/splitByChrom.o",
            "stderr": "splitByChrom/$(inputs.chromosome)/splitByChrom.e",
            "id": "#splitByChrom.cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0002-0929-8603",
                    "https://schema.org/email": "mailto:elise.larsonneur@cea.fr",
                    "https://schema.org/name": "Elise Larsonneur"
                }
            ],
            "https://schema.org/citation": "https://dx.doi.org/10.1109/BIBM.2018.8621141",
            "https://schema.org/codeRepository": "https://github.com/CNRGH/WMS-benchmark",
            "https://schema.org/license": "https://spdx.org/licenses/CECILL-2.1"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/version/latest/schema.rdf",
        "http://edamontology.org/EDAM_1.21.owl"
    ],
    "$namespaces": {
        "s": "https://schema.org/",
        "edam": "http://edamontology.org/"
    }
}
